.. vim: set fileencoding=utf-8 :

.. _bob.pad.face:

========================================================
Library for Facial Presentation Attack Detection (PAD)
========================================================

The Facial Presentation Attack Detection Library is an open-source tool consisting of a
series of plugins for :ref:`bob.pad.base`, our open-source presentation attack detection
platform. As a result, it is fully extensible using :ref:`bob.pad.base` documented
types and techniques. Please refer to the manual of that package for a thorough
introduction. In this guide, we focus on details concerning
face PAD experiments using our plugins.

Users Guide
=============

.. toctree::
   :maxdepth: 2

   installation
   baselines
   other_pad_algorithms
   references
   resources
   api

.. todolist::

.. include:: links.rst
